*******
Authors
*******

pyspotify 2.x is copyright 2013-2015 Stein Magnus Jodal and contributors.
pyspotify is licensed under the Apache License, Version 2.0.

Thanks to Thomas Adamcik who continuously reviewed code and provided feedback
during the development of pyspotify 2.x.

The following persons have contributed to pyspotify 2.x. The list is in the
order of first contribution. For details on who have contributed what, please
refer to our Git repository.

.. include:: ../AUTHORS

If you want to contribute to pyspotify, see :doc:`contributing`.
